@@ -110,6 +110,9 @@ class BasicInfo(db.Model):
     def get_country_display_english(self):
         return Country.RawFromID(self.country)
 
+    def get_profile(self):
+        return self
+
 
 class ActivationSupport(db.Model):
     activation_token = db.CharField(verbose_name=_("activation token"),
